# WePay SDK for Ruby

[![Source](http://img.shields.io/badge/source-wepay/Ruby–SDK-blue.svg?style=flat-square)](https://github.com/wepay/Ruby-SDK)
[![Latest Stable Version](https://img.shields.io/gem/v/wepay.svg?style=flat-square)](https://rubygems.org/gems/wepay)
[![Total Downloads](https://img.shields.io/gem/dt/wepay.svg?style=flat-square)](https://rubygems.org/gems/wepay)
[![Open Issues](http://img.shields.io/github/issues/wepay/Ruby-SDK.svg?style=flat-square)](https://github.com/wepay/Ruby-SDK/issues)
[![Build Status](http://img.shields.io/travis/wepay/Ruby-SDK/master.svg?style=flat-square)](https://travis-ci.org/wepay/Ruby-SDK)
[![Coverage Status](http://img.shields.io/coveralls/wepay/Ruby-SDK/master.svg?style=flat-square)](https://coveralls.io/r/wepay/Ruby-SDK?branch=master)
[![Code Climate](http://img.shields.io/codeclimate/github/wepay/Ruby-SDK.svg?style=flat-square)](https://codeclimate.com/github/wepay/Ruby-SDK)
[![Code Quality](http://img.shields.io/scrutinizer/g/wepay/Ruby-SDK.svg?style=flat-square)](https://scrutinizer-ci.com/g/wepay/Ruby-SDK)
[![Author](http://img.shields.io/badge/author-@wepay-blue.svg?style=flat-square)](https://github.com/wepay)
[![Author](http://img.shields.io/badge/author-@skyzyx-blue.svg?style=flat-square)](https://github.com/skyzyx)

Check out our developer docs at https://stage.wepay.com/developer for more
information, or you may email <api@wepay.com> if you have any other questions.

This project uses [Semantic Versioning](http://semver.org) for managing
backwards-compatibility.

> **NOTE:** Version 0.2.0 is not strictly backwards-compatible with the earlier 0.0.x versions.

* [API Reference](https://wepay.github.io/Ruby-SDK/)

## Examples

```ruby
client_id = 'your_client_id'
client_secret = 'your_client_secret'
use_stage = true

wepay = WePay::Client.new(client_id, client_secret, use_stage)

# Get the OAuth 2.0 authorization URL. Send the user to this URL to authorize
# the application, then they will return to your `redirect_uri` with a code as
# a GET parameter.
redirect_uri = "http://myexamplesite.com/wepay"
redirect_to(wepay.oauth2_authorize_url(redirect_uri))

# Once you have the OAuth 2.0 code, you can request an access token.
response = wepay.oauth2_token(code, redirect_uri)
access_token = response['access_token']

# Make a call to the `/user` endpoint (which requires no parameters).
response = wepay.call('/user', access_token)

# You may also open a payment account for the user.
response = wepay.call('/account/create', access_token, {
  :name        => "test account",
  :description => "this is only a test"
})
```

## Installation

```ruby
gem 'wepay'
```

And include it in your scripts:

```ruby
require 'wepay'
```


## Testing

Firstly, run `bundle install` to download and install the dependencies.

You can run the tests as follows:

```bash
make test
```


## API Reference

The API Reference is generated by a tool called [YARD](http://yardoc.org). Once it's installed, you can generate
updated documentation by running the following command in the root of the repository.

```bash
make docs
```


## Deploying
The `Makefile` (yes, `Makefile`) has a series of commands to simplify the development and deployment process.

### `make`

Running `make` by itself will show you a list of available sub-commands.

```bash
$ make
all
docs
gem
install
pushdocs
pushgem
tag
test
version
```

### `make pushdocs`
You will need to have write-access to the `wepay/Ruby-SDK` repository on GitHub. You should have already set up:

* Your SSH key with your GitHub account.
* Had your GitHub user given write-access to the repository.

Then you can run:

```bash
make pushdocs
```

You can view your changes at <https://wepay.github.io/Ruby-SDK/>.

### `make pushgem`
You will need to have pulled-down the proper gem credentials first. When prompted, enter your
[RubyGems](http://rubygems.org) password.

Login and view your [RubyGems profile page](https://rubygems.org/profile/edit) to see the proper command.

Then you can run:

```bash
make pushgem
```

If you need to [add an additional gem owner](https://stackoverflow.com/questions/8487218/how-to-add-more-owners-to-a-gem-in-rubygem):

```bash
gem owner wepay -a api@wepay.com
```

You can view your changes at <https://rubygems.org/gems/wepay>.

### `make tag`
You will need to have a [Keybase](https://keybase.io) account first, including setting-up the
[`keybase` CLI tool](https://keybase.io/docs/command_line/prerequisites).

Then you can run:

```bash
make tag
```

You can view your changes in the `SIGNED.md` file.


## Contributing
Here's the process for contributing:

1. Fork Signer to your GitHub account.
2. Clone your GitHub copy of the repository into your local workspace.
3. Write code, fix bugs, and add tests with 100% code coverage.
4. Commit your changes to your local workspace and push them up to your GitHub copy.
5. You submit a GitHub pull request with a description of what the change is.
6. The contribution is reviewed. Maybe there will be some banter back-and-forth in the comments.
7. If all goes well, your pull request will be accepted and your changes are merged in.


## Authors, Copyright & Licensing

* Copyright (c) 2015 [WePay](http://wepay.com)

See also the list of [contributors](https://github.com/wepay/Ruby-SDK/graphs/contributors) who participated in this project.

Licensed for use under the terms of the [Apache 2.0] license.

  [Apache 2.0]: http://opensource.org/licenses/Apache-2.0
